@@ -18,13 +18,18 @@ from jinja2 import Environment, FileSystemLoader
 from docutils.core import publish_parts
 
 from sphinx.locale import _
+from sphinx.util.docutils import docutils_namespace
 from sphinx.util.osutil import ensuredir
-from sphinx.util.jsonimpl import dumps as dump_json
 from sphinx.util.pycompat import htmlescape
 from sphinxcontrib.websupport import errors
 from sphinxcontrib.websupport.search import BaseSearch, SEARCH_ADAPTERS
 from sphinxcontrib.websupport.storage import StorageBackend
 
+try:
+    from sphinxcontrib.serializinghtml.jsonimpl import dumps as dump_json
+except ImportError:
+    from sphinx.util.jsonimpl import dumps as dump_json
+
 if False:
     # For type annotation
     from typing import Dict  # NOQA
@@ -78,6 +83,9 @@ class WebSupport(object):
 
         self._make_base_comment_options()
 
+        extensions = self.confoverrides.setdefault('extensions', [])
+        extensions.append('sphinxcontrib.websupport.builder')
+
     def _init_storage(self, storage):
         if isinstance(storage, StorageBackend):
             self.storage = storage
@@ -126,16 +134,17 @@ class WebSupport(object):
         if not self.srcdir:
             raise RuntimeError('No srcdir associated with WebSupport object')
 
-        from sphinx.application import Sphinx
-        app = Sphinx(self.srcdir, self.srcdir, self.outdir, self.doctreedir,
-                     self.buildername, self.confoverrides, status=self.status,
-                     warning=self.warning)
-        app.builder.set_webinfo(self.staticdir, self.staticroot,  # type: ignore
-                                self.search, self.storage)
+        with docutils_namespace():
+            from sphinx.application import Sphinx
+            app = Sphinx(self.srcdir, self.srcdir, self.outdir, self.doctreedir,
+                         self.buildername, self.confoverrides, status=self.status,
+                         warning=self.warning)
+            app.builder.set_webinfo(self.staticdir, self.staticroot,  # type: ignore
+                                    self.search, self.storage)
 
-        self.storage.pre_build()
-        app.build()
-        self.storage.post_build()
+            self.storage.pre_build()
+            app.build()
+            self.storage.post_build()
 
     def get_globalcontext(self):
         """Load and return the "global context" pickle."""
